errorMessage property
If the Status field is set to ERROR, the
ErrorMessage field contains a description of the error that
caused the synchronization to fail.
Implementation
final String? errorMessage;
If the Status field is set to ERROR, the
ErrorMessage field contains a description of the error that
caused the synchronization to fail.
final String? errorMessage;