rankOrder property
Determines how values should be interpreted.
When the RankOrder field is ASCENDING, higher
numbers are better. For example, a document with a rating score of 10 is
higher ranking than a document with a rating score of 1.
When the RankOrder field is DESCENDING, lower
numbers are better. For example, in a task tracking application, a priority
1 task is more important than a priority 5 task.
Only applies to LONG and DOUBLE fields.
Implementation
final Order? rankOrder;